@@ -9,10 +9,10 @@ class TemplateFactory:
   @staticmethod
   def get_template(module_name: ModuleEnum, name: str) -> BaseTemplate:
     if module_name == ModuleEnum.COMMAND.value:
-      return CommandTemplate(module_name, name)
+      return CommandTemplate(name)
     if module_name == ModuleEnum.GROUP_COMMAND.value:
-      return GroupCommandTemplate(module_name, name)
+      return GroupCommandTemplate(name)
     if module_name == ModuleEnum.CONTROLLER.value:
-      return ControllerTemplate(module_name)
+      return ControllerTemplate(name)
     else:
       raise ValueError(f'Not support module {module_name} yet.')
